django-iprestrict
=================

[![Build Status](https://secure.travis-ci.org/sztamas/django-iprestrict.png)](http://travis-ci.org/sztamas/django-iprestrict)

Django app + middleware to restrict access to all or sections of a Django project by client IP ranges.

Documentation (including installation and configuration) is available on [Read the Docs](http://django-iprestrict.readthedocs.org).

